#!/bin/bash
# Nathan Oyama <nathan.oyama@ibm.com> - Sat Jan  5 04:39:07 STD 2019


SCRIPT_DIR=$(dirname "$(test -L "$0" && readlink "$0" || echo "$0")")
TARGET_PATH="/opt/virgo/repository/ecx-usr" 
TEMP_PATH="/opt/virgo/repository/temp-properties"

# Log
if [ -w /data/log/adminconsole/ ]; then
  LOGFILE="/data/log/adminconsole/properties-update.log"
else
  LOGFILE="/tmp/properties-update.log"
fi
env TZ=UTC date >> $LOGFILE
echo "$0 $@"    >> $LOGFILE 

# Set flag vars to empty.
HELP= QUIET=

while getopts :f:qh opt; do
  case $opt in
    f)  DAT=$OPTARG
      ;;
    h)  HELP=true
      ;;
    q)  QUIET=true
      ;;
    '?') echo "$0: invalid option -$OPTARG. Try $0 -h . Aborting."           >&2 
      exit 1
      ;;
  esac
done
shift $((OPTIND - 1))

if [ $HELP ]; then
  echo "Usage: sudo bash ./isoCompRollback.sh -f DAT_FILE [OPTION]"
  echo "  On IBM Spectrum Protect Plus appliance, use this command to roll back"
  echo "  properties files from a backup collection produced by "
  echo "  isoCompDuplicator.sh . The script also creates a backup archive of " 
  echo "  the current properties files before the rollback."
  echo "Options:"
  echo "  -q : Suppress all normal output."
  echo "  -h : Show this help."
  exit 0
fi

if [ $QUIET ]; then
  2>/dev/null 1>/dev/null bash $0 -f $DAT
  exit $?
fi

# Ensure the script is run by root/sudo.
if [ "$EUID" -ne 0 ]; then
  echo "Permission denied. $(whoami), please use root or sudo. Aborting."    >&2
  exit 1
fi

if [ -z $DAT ] || [ ! -s $DAT ]; then
  echo "You need a valid DAT_FILE for"                     | tee -a $LOGFILE >&2
  echo "$ sudo bash ./isoCompRollback.sh -f DAT_FILE"      | tee -a $LOGFILE >&2
  echo "Currently you have the following DAT_FILE(s)"      | tee -a $LOGFILE >&2
  ls -1 $TEMP_PATH/*.dat                                   | tee -a $LOGFILE >&2
  echo "Please use either one."                            | tee -a $LOGFILE >&2
  exit 1
fi

if [ ! -d $TARGET_PATH ]; then
  echo "Could not find the directory \"$TARGET_PATH/\"."   | tee -a $LOGFILE >&2
  echo "Could not retrieve the SPP version. Make sure you" | tee -a $LOGFILE >&2
  echo "are running this script on a valid IBM Spectrum "  | tee -a $LOGFILE >&2
  echo "Protect Plus appliance. Aborting."                 | tee -a $LOGFILE >&2
  exit 1
fi

echo "Creating/overwiting a backup of $TARGET_PATH"        | tee -a $LOGFILE
FILENAME_BAK="/tmp/propertiesBackup.tar.gz"
2> /dev/null 1> /dev/null tar -czf $FILENAME_BAK $TARGET_PATH
if [ $? -eq 0 ] && [ -s $FILENAME_BAK ]; then
  echo "The backup $FILENAME_BAK was created/overwriten."  | tee -a $LOGFILE
else
  echo "Unable to create a backup. Aborting."              | tee -a $LOGFILE >&2
  exit 1
fi

rm -fv $TARGET_PATH/*.properties                                 >> $LOGFILE
echo "$(paste <(cat $DAT) \
  <(rev $DAT | cut -d '.' -f 5- | cut -d '/' -f 1 | rev))" \
  | while read -r line1 line2; do
  cp -v $line1 $TARGET_PATH/$line2                               >> $LOGFILE

  if [ ! $? -eq 0 ]; then
    echo "Failed to rollback $line2 . Aborting."           | tee -a $LOGFILE >&2
    exit 1
  fi
done

echo "Total files: $(wc -l $DAT | cut -d ' ' -f 1)"        | tee -a $LOGFILE
echo "Rollback destination: $TARGET_PATH"                  | tee -a $LOGFILE
echo "Rollback operation has been done successfully."      | tee -a $LOGFILE

exit $?

